EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Applications_CreateApplication',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Application_Id',
    /* Description_Text        */ 'Creates a new application.'
GO

IF OBJECT_ID('[Applications_CreateApplication]') IS NOT NULL DROP PROCEDURE [Applications_CreateApplication]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Applications_CreateApplication]
(
	@Application_Name VARCHAR(50),
	@ReleaseNumber_Scheme_Name VARCHAR(20) = NULL,
	@BuildNumber_Scheme_Name VARCHAR(15) = NULL,
	@ApplicationGroup_Id INT = NULL,
	@CreatedBy_User_Name USERNAME = NULL,
	@CreatedOn_Date DATETIME = NULL,
	@ModifiedBy_User_Name USERNAME = NULL,
	@ModifiedOn_Date DATETIME = NULL,
	@Application_Description VARCHAR(MAX) = NULL,
	@ApplicationConfiguration_Xml XML = NULL,
	@Application_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON 

BEGIN TRY
	BEGIN TRANSACTION

	/* Set defaults */
	SET @ReleaseNumber_Scheme_Name = ISNULL(@ReleaseNumber_Scheme_Name, 'MajorMinor')
	SET @BuildNumber_Scheme_Name = ISNULL(@BuildNumber_Scheme_Name, 'Sequential')

	INSERT INTO [Applications]
	(
		[Application_Name], 
		[ReleaseNumber_Scheme_Name],
		[BuildNumber_Scheme_Name],
		[ApplicationGroup_Id],
		[CreatedBy_User_Name],
		[CreatedOn_Date],
		[ModifiedBy_User_Name],
		[ModifiedOn_Date],
		[Application_Description],
		[ApplicationConfiguration_Xml]
	)
	VALUES
	(
		@Application_Name,
		@ReleaseNumber_Scheme_Name,
		@BuildNumber_Scheme_Name,
		@ApplicationGroup_Id,
		COALESCE(@CreatedBy_User_Name, dbo.Session_GetUserName()),
		COALESCE(@CreatedOn_Date, GETUTCDATE()),
		COALESCE(@ModifiedBy_User_Name, dbo.Session_GetUserName()),
		COALESCE(@ModifiedOn_Date, GETUTCDATE()),
		@Application_Description,
		@ApplicationConfiguration_Xml
	)
	SET @Application_Id = SCOPE_IDENTITY()
	
	/* Raise Event */
	EXEC [Events_RaiseEvent] 'APPNEW',@Application_Id

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Applications_CreateApplication] TO [BuildMasterUser_Role]
