EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'ConfigurationFiles_ImportConfigurationFile',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'ConfigurationFile_Id',
    /* Description_Text        */ 'Imports a configuration file.'
GO

IF OBJECT_ID('[ConfigurationFiles_ImportConfigurationFile]') IS NOT NULL DROP PROCEDURE [ConfigurationFiles_ImportConfigurationFile]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [ConfigurationFiles_ImportConfigurationFile]
(
	@Application_Id INT,
	@Deployable_Id INT,
	@FilePath_Text VARCHAR(500),
	@ConfigurationFile_Name NVARCHAR(100),
	@Description_Text NVARCHAR(MAX),
	@Active_Indicator YNINDICATOR,
	@CreatedBy_User_Name USERNAME,
	@CreatedOn_Date DATETIME,
	@ModifiedBy_User_Name USERNAME,
	@ModifiedOn_Date DATETIME,
	@ConfigurationFile_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	INSERT INTO [ConfigurationFiles] 
	(
		[Deployable_Id],
		[FilePath_Text],
		[Active_Indicator],
		[CreatedBy_User_Name],
		[CreatedOn_Date],
		[ModifiedBy_User_Name],
		[ModifiedOn_Date],
		[ConfigurationFile_Name],
		[Description_Text],
		[Application_Id]
	)
	VALUES
	(
		@Deployable_Id,
		@FilePath_Text,
		@Active_Indicator,
		@CreatedBy_User_Name,
		@CreatedOn_Date,
		@ModifiedBy_User_Name,
		@ModifiedOn_Date,
		@ConfigurationFile_Name,
		@Description_Text,
		@Application_Id
	)

	SET @ConfigurationFile_Id = SCOPE_IDENTITY()

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [ConfigurationFiles_ImportConfigurationFile] TO [BuildMasterUser_Role]
