EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'ConfigurationFiles_PurgeConfigurationFileInstance',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Purges a configuration file instance, including all previous versions and deployment history.'
GO

IF OBJECT_ID('[ConfigurationFiles_PurgeConfigurationFileInstance]') IS NOT NULL DROP PROCEDURE [ConfigurationFiles_PurgeConfigurationFileInstance]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [ConfigurationFiles_PurgeConfigurationFileInstance]
(
	@ConfigurationFile_Id INT,
	@Instance_Name VARCHAR(100),
	@UnlinkTemplate_Indicator YNINDICATOR
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	DECLARE @Application_Id INT
	SELECT @Application_Id = [Application_Id]
	  FROM [ConfigurationFiles]
	 WHERE [ConfigurationFile_Id] = @ConfigurationFile_Id

	IF @UnlinkTemplate_Indicator = 'Y'
	BEGIN
		UPDATE [ConfigurationFileInstances]
		   SET [Template_Instance_Name] = NULL
		 WHERE [ConfigurationFile_Id] = @ConfigurationFile_Id
		   AND [Template_Instance_Name] = @Instance_Name
	END

	DELETE [ConfigurationFileDeployments]
	 WHERE [ConfigurationFile_Id] = @ConfigurationFile_Id
	   AND [Instance_Name] = @Instance_Name

	DELETE [ConfigurationFileVersions]
	 WHERE [ConfigurationFile_Id] = @ConfigurationFile_Id
	   AND [Instance_Name] = @Instance_Name

    DELETE [ConfigurationFileInstances]
     WHERE [ConfigurationFile_Id] = @ConfigurationFile_Id
       AND [Instance_Name] = @Instance_Name

	EXEC [Events_RaiseEvent] 'CFGDLI', @Application_Id, @ConfigurationFile_Id, @Instance_Name

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [ConfigurationFiles_PurgeConfigurationFileInstance] TO [BuildMasterUser_Role]
