EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Releases_GetReleases',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'DataTable',
    /* DataTableNames_Csv      */ 'Releases_Extended',
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Gets a list of releases that match the specified criteria.'
GO


IF OBJECT_ID('[Releases_GetReleases]') IS NOT NULL DROP PROCEDURE [Releases_GetReleases]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Releases_GetReleases]
(
	@Application_Id INT,
	@ReleaseStatus_Name VARCHAR(9) = NULL,
	@Pipeline_Name VARCHAR(50) = NULL,
	@Deployable_Name VARCHAR(50) = NULL,
	@Release_Count INT = NULL
)
AS
BEGIN

	SET NOCOUNT ON

	IF @Release_Count IS NOT NULL
		SET ROWCOUNT @Release_Count

	SELECT R.*
	  FROM [Releases_Extended] R
	  LEFT JOIN [ReleaseDeployables_Extended] RD
	         ON RD.[Release_Id] = R.[Release_Id]
	        AND RD.[Deployable_Name] = @Deployable_Name
     WHERE (@Application_Id IS NULL OR R.[Application_Id] = @Application_Id)
	   AND (@ReleaseStatus_Name IS NULL OR R.[ReleaseStatus_Name] = @ReleaseStatus_Name)
	   AND (@Pipeline_Name IS NULL OR R.[Pipeline_Name] = @Pipeline_Name)
	   AND (@Deployable_Name IS NULL OR RD.[Deployable_Name] = @Deployable_Name)
      ORDER BY CASE WHEN @Application_Id IS NULL THEN R.[Latest_Promoted_Date] ELSE R.[Release_Sequence] END DESC

END
GO

GRANT EXECUTE ON [Releases_GetReleases] TO [BuildMasterUser_Role]
